@@ -1,6 +1,7 @@
 package Physics::Unit;
 
 use strict;
+use warnings;
 use Carp;
 use base qw(Exporter);
 use vars qw(
@@ -11,7 +12,7 @@ use vars qw(
     $number_re
 );
 
-$VERSION = '0.53';
+$VERSION = '0.54';
 $VERSION = eval $VERSION;
 
 @EXPORT_OK = qw(
@@ -100,12 +101,12 @@ InitPrefix (
     'yocto',   1e-24,
 
     # binary prefixes
-    'kibi',    2^10,
-    'mebi',    2^20,
-    'gibi',    2^30,
-    'tebi',    2^40,
-    'pebi',    2^50,
-    'exbi',    2^60,
+    'kibi',    2**10,
+    'mebi',    2**20,
+    'gibi',    2**30,
+    'tebi',    2**40,
+    'pebi',    2**50,
+    'exbi',    2**60,
 
     # others
     'semi',    0.5,
@@ -193,6 +194,7 @@ InitUnit (
     ['cm',],                                    'centimeter',       # exact
     ['km',],                                    'kilometer',        # exact
     ['nm',],                                    'nanometer',        # exact
+    ['mm',],                                    'millimeter',       # exact
 
     ['pica',],                                  'in/6',    # exact, but see below
     ['point',],                                 'pica/12',          # exact
